@@ -4,7 +4,7 @@ from typing import List
 
 from jsonrpcclient.clients.http_client import HTTPClient
 
-from app import logging
+import logging
 from common.cs_enum import AutoName
 
 DEFAULT_LEDGER_BOOK_ID = "1"
